CMPageTitle class

A widget that displays a page title with customizable styles and an optional bottom divider.

The CMPageTitle widget is used to create a page title with a combination of light and bold text. It allows you to specify two strings: lightTitle and boldTitle, where the first is styled with a lighter font weight and the second with a bolder font weight. Also, you can control the visibility of a bottom divider using the showBottomDivider property. Additionally yo can show an edit icon on the right of the boldTitle.

This widget is useful for displaying section headers or titles in a consistent manner, with the ability to adjust text styles and layout.

Example usage:

CMPageTitle(
  lightTitle: "Welcome to",
  boldTitle: "Flutter",
  showBottomDivider: true,
);
Inheritance

Constructors

CMPageTitle({Key? key, required String lightTitle, required String boldTitle, bool showBottomDivider = true, bool showEditIcon = false})
const

Properties

boldTitle String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lightTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBottomDivider bool
final
showEditIcon bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited