SelectableServiceTypeItem class
Properties
-
description
→ String
-
Descriptive label for the service type option.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
icon
→ String
-
Path or asset name of the service type icon.
final
-
id
→ String
-
Unique identifier for the service type option.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
title
→ String
-
Title label for the service type option.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited